Crate datafusion_execution

Crate datafusion_execution 

DataFusion execution configuration and runtime structures

Re-exports

pub use disk_manager::DiskManager;
pub use spill_file::SpillFile;
pub use spill_file::SpillWriter;
pub use spill_file::TempFileFactory;

Modules

cache
config
disk_manager
DiskManager: Manages files generated during query execution
memory_pool
MemoryPool for memory management during query execution, proxy for help with allocation accounting.
object_store
ObjectStoreRegistry holds all the object stores at Runtime with a scheme for each store. This allows the user to extend DataFusion with different storage systems such as S3 or HDFS and query data inside these systems.
parquet_encryptionparquet_encryption
registry
runtime_env
Execution RuntimeEnv environment that manages access to object store, memory manager, disk manager.
spill_file

Structs

Emitter
A handle for emitting values from an async_stream generator.
TaskContext
Task Execution Context
TryEmitter
A handle for emitting values from an async_try_stream generator.

Traits

FunctionRegistry
A registry knows how to build logical expressions out of user-defined function’ names
RecordBatchStream
Trait for types that stream RecordBatch
TaskContextProvider
Produce the TaskContext.

Functions

async_stream
Creates a Stream from an async generator function.
async_try_stream
Creates a fallible Stream from an async generator function.

Type Aliases

SendableRecordBatchStream
Trait for a Stream of RecordBatches that can be passed between threads