Module cache

Module cache 

Modules

cache_manager
default_cache
lru_queue

Structs

CacheEntryInfo
SchemaFingerprint
A fingerprint of the file_schema used to compute a file’s statistics.
TableScopedPath
Each entry is scoped to its use within a specific table so that the cache can differentiate between identical paths in different tables, and table-level cache invalidation.

Traits

Cache
Base trait for cache implementations with common operations.
CacheKey
Key type for entries stored in a Cache.
CacheValue
Value type for entries stored in a Cache.