Structs
- Cache
Manager - Manages various caches used in DataFusion.
- Cache
Manager Config - Cached
File List - Cached file listing.
- Cached
File Metadata - Cached metadata for a file, including statistics and ordering.
- Cached
File Metadata Entry - Cached file metadata entry with validation information.
- File
Metadata Cache Entry - Represents information about a cached metadata entry. This is used to expose the metadata cache contents to outside modules.
- File
Statistics Cache Entry - Represents information about a cached statistics entry. This is used to expose the statistics cache contents to outside modules.
Constants
- DEFAULT_
LIST_ FILES_ CACHE_ MEMORY_ LIMIT - The default memory limit for the
DefaultListFilesCache - DEFAULT_
LIST_ FILES_ CACHE_ TTL - The default cache TTL for the
DefaultListFilesCache - DEFAULT_
METADATA_ CACHE_ LIMIT
Traits
- File
Metadata - Generic file-embedded metadata used with
FileMetadataCache. - File
Metadata Cache - Cache for file-embedded metadata.
- File
Statistics Cache - A cache for file statistics and orderings.
- List
Files Cache - Cache for storing the
ObjectMetas that result from listing a path