pub struct CachedFileList {
pub files: Arc<Vec<ObjectMeta>>,
}Expand description
Cached file listing.
TTL expiration is handled internally by the cache implementation.
Fields
files: Arc<Vec<ObjectMeta>>The cached file list.
Implementations
Sourceimpl CachedFileList
impl CachedFileList
Sourcepub fn new(files: Vec<ObjectMeta>) -> Self
pub fn new(files: Vec<ObjectMeta>) -> Self
Create a new cached file list.
Sourcepub fn files_matching_prefix(
&self,
prefix: &Option<Path>,
) -> Arc<Vec<ObjectMeta>>
pub fn files_matching_prefix( &self, prefix: &Option<Path>, ) -> Arc<Vec<ObjectMeta>>
Returns files matching the given prefix.
When prefix is None, returns a clone of the Arc (no data copy).
When filtering is needed, returns a new Arc with filtered results (clones each matching ObjectMeta).