pub struct DefaultFileStatisticsCache { /* private fields */ }Expand description
Default implementation of FileStatisticsCache
Stores cached file metadata (statistics and orderings) for files.
The typical usage pattern is:
- Call
get(path)to check for cached value - If
Some(cached), validate withcached.is_valid_for(¤t_meta) - If invalid or missing, compute new value and call
put(path, new_value)
Internal details
The memory_limit controls the maximum size of the cache, which uses a
Least Recently Used eviction algorithm. When adding a new entry, if the total
size of the cached entries exceeds memory_limit, the least recently used entries
are evicted until the total size is lower than memory_limit.
Implementations