TableScopedPath

Struct TableScopedPath 

pub struct TableScopedPath {
    pub table: Option<TableReference>,
    pub path: Path,
}
Each entry is scoped to its use within a specific table so that the cache can differentiate between identical paths in different tables, and table-level cache invalidation.

Fields

table: Option<TableReference>path: Path