DiskManager

Struct DiskManager 

pub struct DiskManager { /* private fields */ }
Manages files generated during query execution, e.g. spill files generated while processing dataset larger than available memory.

Implementations

Source

impl DiskManager

pub fn builder() -> DiskManagerBuilder

Creates a builder for DiskManager

pub fn set_max_temp_directory_size( &self, max_temp_directory_size: u64, ) -> Result<()>

Atomically set the max temp directory size at runtime.

Takes &self, so it works through Arc<DiskManager> without requiring exclusive access. Takes effect immediately for subsequent spill writes.

Use this when you need to adjust the limit dynamically while queries are running (e.g., adapting to available disk space).

pub fn set_arc_max_temp_directory_size( this: &Arc<Self>, max_temp_directory_size: u64, ) -> Result<()>

👎Deprecated since 54.0.0:

Use set_max_temp_directory_size directly, it now takes &self

pub fn with_max_temp_directory_size( self, max_temp_directory_size: u64, ) -> Result<Self>

pub fn used_disk_space(&self) -> u64

pub fn max_temp_directory_size(&self) -> u64

Returns the maximum temporary directory size in bytes

pub fn set_max_spill_merge_fan_in(&self, max_spill_merge_fan_in: usize)

Atomically set the maximum spill merge fan-in.

A value of 0 disables the cap. Values of 1 are accepted but external merge code will still merge at least two spill streams to make progress.

pub fn max_spill_merge_fan_in(&self) -> usize

Returns the maximum number of spill files opened by one merge pass.

A value of 0 means unlimited.

pub fn spilling_progress(&self) -> SpillingProgress

Returns the current spilling progress

pub fn temp_dir_paths(&self) -> Vec<PathBuf>

Returns the temporary directory paths

pub fn tmp_files_enabled(&self) -> bool

Return true if this disk manager supports creating temporary files. If this returns false, any call to create_tmp_file will error.

pub fn create_tmp_file( self: &Arc<Self>, request_description: &str, ) -> Result<Arc<dyn SpillFile>>

Return a temporary file from a randomized choice in the configured locations

If the file can not be created for some reason, returns an error message referencing the request description