pub struct DiskManagerBuilder { /* private fields */ }Expand description
Builder pattern for the DiskManager structure
Implementations
Sourceimpl DiskManagerBuilder
impl DiskManagerBuilder
pub fn set_mode(&mut self, mode: DiskManagerMode)
pub fn with_mode(self, mode: DiskManagerMode) -> Self
Sourcepub fn set_temp_file_factory(
&mut self,
temp_file_factory: Arc<dyn TempFileFactory>,
)
pub fn set_temp_file_factory( &mut self, temp_file_factory: Arc<dyn TempFileFactory>, )
Configure a custom factory for creating temporary spill files.
This sets the disk manager mode to DiskManagerMode::Custom, so
operators that spill during query execution create files through the
provided TempFileFactory instead of using local temporary files.
Sourcepub fn with_temp_file_factory(
self,
temp_file_factory: Arc<dyn TempFileFactory>,
) -> Self
pub fn with_temp_file_factory( self, temp_file_factory: Arc<dyn TempFileFactory>, ) -> Self
Configure a custom factory for creating temporary spill files.
See details on Self::set_temp_file_factory.
pub fn set_max_temp_directory_size(&mut self, value: u64)
pub fn with_max_temp_directory_size(self, value: u64) -> Self
pub fn set_max_spill_merge_fan_in(&mut self, value: usize)
pub fn with_max_spill_merge_fan_in(self, value: usize) -> Self
Sourcepub fn build(self) -> Result<DiskManager>
pub fn build(self) -> Result<DiskManager>
Create a DiskManager given the builder