RefCountedTempFile

Struct RefCountedTempFile 

pub struct RefCountedTempFile { /* private fields */ }
A wrapper around a NamedTempFile that also contains a reference to its parent temporary directory.

This type is Clone-able, allowing multiple references to the same underlying file. The file is deleted only when the last reference is dropped.

The parent temporary directory is also kept alive as long as any reference to this file exists, preventing premature cleanup of the directory.

Once all references to this file are dropped, the file is deleted, and the disk usage is subtracted from the disk manager’s total.

Implementations