pub struct MemoryConsumerMetrics {
pub name: String,
pub can_spill: bool,
pub reserved: usize,
pub peak: usize,
}Expand description
A point-in-time snapshot of a tracked memory consumer’s state.
Returned by TrackConsumersPool::metrics().
Fields
name: StringThe name of the memory consumer
can_spill: boolWhether this consumer can spill to disk
reserved: usizeThe number of bytes currently reserved by this consumer
peak: usizeThe peak number of bytes reserved by this consumer