pub struct MemoryReservation { /* private fields */ }Expand description
A MemoryReservation tracks an individual reservation of a
number of bytes of memory in a MemoryPool that is freed back
to the pool on drop.
The reservation can be grown or shrunk over time.
Implementations
Sourceimpl MemoryReservation
impl MemoryReservation
Sourcepub fn consumer(&self) -> &MemoryConsumer
pub fn consumer(&self) -> &MemoryConsumer
Returns MemoryConsumer for this MemoryReservation
Sourcepub fn free(&self) -> usize
pub fn free(&self) -> usize
Frees all bytes from this reservation back to the underlying pool, returning the number of bytes freed.
Sourcepub fn try_shrink(&self, capacity: usize) -> Result<usize>
pub fn try_shrink(&self, capacity: usize) -> Result<usize>
Tries to free capacity bytes from this reservation
if capacity does not exceed Self::size.
Returns new reservation size,
or error if shrinking capacity is more than allocated size.
Sourcepub fn try_resize(&self, capacity: usize) -> Result<()>
pub fn try_resize(&self, capacity: usize) -> Result<()>
Try to set the size of this reservation to capacity
Sourcepub fn try_grow(&self, capacity: usize) -> Result<()>
pub fn try_grow(&self, capacity: usize) -> Result<()>
Try to increase the size of this reservation by capacity
bytes, returning error if there is insufficient capacity left
in the pool.
Sourcepub fn split(&self, capacity: usize) -> MemoryReservation
pub fn split(&self, capacity: usize) -> MemoryReservation
Splits off capacity bytes from this MemoryReservation
into a new MemoryReservation with the same
MemoryConsumer.
This can be useful to free part of this reservation with RAAI style dropping
Panics
Panics if capacity exceeds Self::size
Sourcepub fn new_empty(&self) -> Self
pub fn new_empty(&self) -> Self
Returns a new empty MemoryReservation with the same MemoryConsumer
Sourcepub fn take(&mut self) -> MemoryReservation
pub fn take(&mut self) -> MemoryReservation
Splits off all the bytes from this MemoryReservation into
a new MemoryReservation with the same MemoryConsumer