pub struct TryEmitter<T, E> { /* private fields */ }Expand description
A handle for emitting values from an async_try_stream generator.
The generator closure receives a TryEmitter<T, E> as its argument.
Implementations
Sourceimpl<T, E> TryEmitter<T, E>
impl<T, E> TryEmitter<T, E>
Sourcepub fn emit(&mut self, value: T) -> impl FusedFuture<Output = ()>
pub fn emit(&mut self, value: T) -> impl FusedFuture<Output = ()>
Emits Ok(value) as the next stream item and suspends the generator.
Behaves identically to Emitter::emit: the returned future must be
awaited immediately and yields Poll::Pending on its first poll to
transfer control to the stream consumer.
Panics
Panics if called before the previous emit future has been awaited.