DataFusion execution configuration and runtime structures
Re-exports
pub use disk_manager::DiskManager;pub use spill_file::SpillFile;pub use spill_file::SpillWriter;pub use spill_file::TempFileFactory;
Modules
- cache
- config
- disk_
manager DiskManager: Manages files generated during query execution- memory_
pool MemoryPoolfor memory management during query execution,proxyfor help with allocation accounting.- object_
store - ObjectStoreRegistry holds all the object stores at Runtime with a scheme for each store. This allows the user to extend DataFusion with different storage systems such as S3 or HDFS and query data inside these systems.
- parquet_
encryption parquet_encryption - registry
- runtime_
env - Execution
RuntimeEnvenvironment that manages access to object store, memory manager, disk manager. - spill_
file
Structs
- Emitter
- A handle for emitting values from an
async_streamgenerator. - Task
Context - Task Execution Context
- TryEmitter
- A handle for emitting values from an
async_try_streamgenerator.
Traits
- Function
Registry - A registry knows how to build logical expressions out of user-defined function’ names
- Record
Batch Stream - Trait for types that stream RecordBatch
- Task
Context Provider - Produce the
TaskContext.
Functions
- async_
stream - Creates a
Streamfrom an async generator function. - async_
try_ stream - Creates a fallible
Streamfrom an async generator function.
Type Aliases
- Sendable
Record Batch Stream - Trait for a
StreamofRecordBatches that can be passed between threads