Modules
Structs
- Cache
Entry Info - Schema
Fingerprint - A fingerprint of the
file_schemaused to compute a file’s statistics. - Table
Scoped Path - Each entry is scoped to its use within a specific table so that the cache can differentiate between identical paths in different tables, and table-level cache invalidation.
Traits
- Cache
- Base trait for cache implementations with common operations.
- Cache
Key - Key type for entries stored in a
Cache. - Cache
Value - Value type for entries stored in a
Cache.