pub struct DefaultFilesMetadataCache { /* private fields */ }Expand description
Default implementation of FileMetadataCache
Collected file embedded metadata cache.
The metadata for each file is validated by comparing the cached ObjectMeta
(size and last_modified) against the current file state using cached.is_valid_for(¤t_meta).
Internal details
The memory_limit controls the maximum size of the cache, which uses a
Least Recently Used eviction algorithm. When adding a new entry, if the total
size of the cached entries exceeds memory_limit, the least recently used entries
are evicted until the total size is lower than memory_limit.
Implementations
Sourceimpl DefaultFilesMetadataCache
impl DefaultFilesMetadataCache
Sourcepub fn new(memory_limit: usize) -> Self
pub fn new(memory_limit: usize) -> Self
Create a new instance of DefaultFilesMetadataCache.
Arguments
memory_limit: the maximum size of the cache, in bytes
Sourcepub fn memory_used(&self) -> usize
pub fn memory_used(&self) -> usize
Returns the size of the cached memory, in bytes.