pub struct DefaultListFilesCache { /* private fields */ }Expand description
Default implementation of ListFilesCache
Caches file metadata for file listing operations.
Internal details
The memory_limit parameter controls the maximum size of the cache, which uses a Least
Recently Used eviction algorithm. When adding a new entry, if the total number of entries in
the cache exceeds memory_limit, the least recently used entries are evicted until the total
size is lower than the memory_limit.
Extra Handling
Users should use the Self::get and Self::put methods. The
Self::get_with_extra and Self::put_with_extra methods simply call
get and put, respectively.
Implementations
Sourceimpl DefaultListFilesCache
impl DefaultListFilesCache
Sourcepub fn new(memory_limit: usize, ttl: Option<Duration>) -> Self
pub fn new(memory_limit: usize, ttl: Option<Duration>) -> Self
Creates a new instance of DefaultListFilesCache.
Arguments
memory_limit- The maximum size of the cache, in bytes.ttl- The TTL (time-to-live) of entries in the cache.
Sourcepub fn cache_limit(&self) -> usize
pub fn cache_limit(&self) -> usize
Returns the cache’s memory limit in bytes.
Sourcepub fn update_cache_limit(&self, limit: usize)
pub fn update_cache_limit(&self, limit: usize)
Updates the cache with a new memory limit in bytes.