pub struct TableScopedPath {
pub table: Option<TableReference>,
pub path: Path,
}Expand description
Key for DefaultListFilesCache
Each entry is scoped to its use within a specific table so that the cache can differentiate between identical paths in different tables, and table-level cache invalidation.
Fields
table: Option<TableReference>path: PathTrait Implementations
Sourceimpl CacheAccessor<TableScopedPath, CachedFileList> for DefaultListFilesCache
impl CacheAccessor<TableScopedPath, CachedFileList> for DefaultListFilesCache
Sourcefn get(&self, key: &TableScopedPath) -> Option<CachedFileList>
fn get(&self, key: &TableScopedPath) -> Option<CachedFileList>
Get a cached entry if it exists. Read more
Sourcefn put(
&self,
key: &TableScopedPath,
value: CachedFileList,
) -> Option<CachedFileList>
fn put( &self, key: &TableScopedPath, value: CachedFileList, ) -> Option<CachedFileList>
Store a value in the cache. Read more
Sourcefn remove(&self, k: &TableScopedPath) -> Option<CachedFileList>
fn remove(&self, k: &TableScopedPath) -> Option<CachedFileList>
Remove an entry from the cache, returning the value if it existed.
Sourcefn contains_key(&self, k: &TableScopedPath) -> bool
fn contains_key(&self, k: &TableScopedPath) -> bool
Check if the cache contains a specific key.
Sourceimpl Clone for TableScopedPath
impl Clone for TableScopedPath
Sourcefn clone(&self) -> TableScopedPath
fn clone(&self) -> TableScopedPath
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableScopedPath
impl Debug for TableScopedPath
Sourceimpl Hash for TableScopedPath
impl Hash for TableScopedPath
Sourceimpl PartialEq for TableScopedPath
impl PartialEq for TableScopedPath
impl Eq for TableScopedPath
impl StructuralPartialEq for TableScopedPath